Summary: Delivery framework for general Input Method configuration
Name:    imsettings
Version: 1.8.7
Release: 3%{?dist}
License: LGPL-2.0-or-later
URL:     https://gitlab.com/tagoh/%{name}/
Source0: https://gitlab.com/tagoh/%{name}/-/archive/%{version}/%{name}-%{version}.tar.bz2
Patch0000: %{name}-constraint-of-language.patch
Patch0001: %{name}-disable-xim.patch
Patch0002: %{name}-xinput-xcompose.patch
Patch0003: %{name}-force-enable-for-cinnamon.patch

BuildRequires: desktop-file-utils, gettext-devel, libnotify-devel, libX11-devel
BuildRequires: glib2-devel >= 2.32.0, gobject-introspection-devel, gtk3-devel >= 3.3.3, gtk-doc
BuildRequires: libtool, automake, autoconf, autoconf-archive, make

Requires:	xorg-x11-xinit
Requires:	%{name}-libs = %{version}-%{release}
Requires:	%{name}-desktop-module = %{version}-%{release}
Requires(post):	systemd %{_sbindir}/alternatives
Requires(postun):	systemd %{_sbindir}/alternatives
Requires:	/bin/bash
Suggests:	%{name}-gsettings

%description
IMSettings is a framework that delivers Input Method
settings and applies the changes so they take effect
immediately without any need to restart applications
or the desktop.
.
This package contains the core DBus services and some utilities.

%package	libs
Summary:	Libraries for imsettings

%description	libs
IMSettings is a framework that delivers Input Method
settings and applies the changes so they take effect
immediately without any need to restart applications
or the desktop.
.
This package contains the shared library for imsettings.

%package	devel
Summary:	Development files for imsettings
Requires:	%{name}-libs = %{version}-%{release}
Requires:	pkgconfig
Requires:	glib2-devel >= 2.32.0

%description	devel
IMSettings is a framework that delivers Input Method
settings and applies the changes so they take effect
immediately without any need to restart applications
or the desktop.
.
This package contains the development files to make any
applications with imsettings.

%package	gsettings
Summary:	GSettings support on imsettings
Requires:	%{name} = %{version}-%{release}
Requires:	dconf
Provides:	imsettings-desktop-module = %{version}-%{release}
Provides:	%{name}-gnome = %{version}-%{release}
Provides:	%{name}-systemd = %{version}-%{release}

%description	gsettings
IMSettings is a framework that delivers Input Method
settings and applies the changes so they take effect
immediately without any need to restart applications
or the desktop.
.
This package contains a module to get this working on
GNOME and Cinnamon which requires GSettings in their
own XSETTINGS daemons.

%package	qt
Summary:	Qt support on imsettings
Requires:	%{name} = %{version}-%{release}
Requires:	im-chooser
Provides:	imsettings-desktop-module = %{version}-%{release}

%description	qt
IMSettings is a framework that delivers Input Method
settings and applies the changes so they take effect
immediately without any need to restart applications
or the desktop.
.
This package contains a module to get this working on Qt
applications.

%package	plasma
Summary:	Plasma Workspace support on imsettings
Requires:	%{name} = %{version}-%{release}
Requires:	im-chooser
Requires:	kf5-filesystem
Provides:	imsettings-desktop-module = %{version}-%{release}

%description	plasma
IMSettings is a framework that delivers Input Method
settings and applies the changes so they take effect
immediately without any need to restart applications
or the desktop.
.
This package contains Plasma Workspace support on
imsettings.



%prep
%autosetup -p1



%build
autoreconf -i
%configure	\
	--with-xinputsh=50-xinput.sh \
	--disable-static \
	--disable-schemas-install

%make_build



%install
%make_install

chmod 0755 %{buildroot}%{_libexecdir}/imsettings-target-checker.sh
chmod 0755 %{buildroot}%{_libexecdir}/xinputinfo.sh
chmod 0755 %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/50-xinput.sh

install -d %{buildroot}%{_sysconfdir}/xdg/plasma-workspace/env
ln -sf $(realpath --relative-to=%{buildroot}%{_sysconfdir}/xdg/plasma-workspace/env/ %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/)/50-xinput.sh %{buildroot}%{_sysconfdir}/xdg/plasma-workspace/env/xinput.sh

rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/imsettings/*.la
rm -f %{buildroot}%{_libdir}/imsettings/libimsettings-{gconf,mateconf,systemd-gtk,systemd-qt}.so
rm -f %{buildroot}%{_libdir}/imsettings/libimsettings-{lxde,xfce,xim,cinnamon-gsettings,mate,mate-gsettings}.so
desktop-file-validate %{buildroot}%{_sysconfdir}/xdg/autostart/imsettings-start.desktop

%find_lang %{name}


%check
#skip gui check in tty



%post
alternatives --install %{_sysconfdir}/X11/xinit/xinputrc xinputrc %{_sysconfdir}/X11/xinit/xinput.d/none.conf 10
alternatives --install %{_sysconfdir}/X11/xinit/xinputrc xinputrc %{_sysconfdir}/X11/xinit/xinput.d/xcompose.conf 20
alternatives --install %{_sysconfdir}/X11/xinit/xinputrc xinputrc %{_sysconfdir}/X11/xinit/xinput.d/xim.conf 30
systemctl reload dbus.service 2>&1 || :

%postun
if [ "$1" = 0 ]; then
	alternatives --remove xinputrc %{_sysconfdir}/X11/xinit/xinput.d/none.conf
	alternatives --remove xinputrc %{_sysconfdir}/X11/xinit/xinput.d/xcompose.conf
	alternatives --remove xinputrc %{_sysconfdir}/X11/xinit/xinput.d/xim.conf
	systemctl reload dbus.service 2>&1 || :
fi



%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig



%files	-f %{name}.lang
%license COPYING
%doc AUTHORS NEWS README
%dir %{_libdir}/imsettings
%{_bindir}/imsettings-info
%{_bindir}/imsettings-list
%{_bindir}/imsettings-reload
%{_bindir}/imsettings-switch
%{_libexecdir}/imsettings-check
%{_libexecdir}/imsettings-daemon
%{_libexecdir}/xinputinfo.sh
%{_libexecdir}/imsettings-functions
%{_libexecdir}/imsettings-target-checker.sh
%{_datadir}/dbus-1/services/*.service
%{_datadir}/pixmaps/*.png
%{_sysconfdir}/X11/xinit/xinitrc.d/50-xinput.sh
%{_sysconfdir}/X11/xinit/xinput.d
%{_sysconfdir}/xdg/autostart/imsettings-start.desktop
%{_mandir}/man1/imsettings-*.1*

%files	libs
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/libimsettings.so.5*

%files	devel
%license COPYING
%doc AUTHORS NEWS README
%{_includedir}/imsettings
%{_libdir}/libimsettings.so
%{_libdir}/pkgconfig/imsettings.pc
%{_libdir}/girepository-*/IMSettings-*.typelib
%{_datadir}/gir-*/IMSettings-*.gir

%files	gsettings
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/imsettings/libimsettings-gsettings.so

%files	qt
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/imsettings/libimsettings-qt.so

%files	plasma
%license COPYING
%doc AUTHORS NEWS README
%{_sysconfdir}/xdg/plasma-workspace/env/xinput.sh



%changelog
* Thu May 9 2024 Pengda Dou <doupengda@loongson.cn> - 1.8.7-3
- [Type] bugfix
- [DESC] fix url error problem , remove Changlog and imsettings files that aren't there

* Sat Oct 28 2023 Chair <chairou@tencent.com> - 1.8.7-2
- initial

* Sat Oct 28 2023 Chair <chairou@tencent.com> - 1.8.7-1
- initial
